#------------------------------------------------------------------------------------------------
# Permission to use, copy, modify, and distribute this software for 
# any purpose and without fee is hereby granted.
#
# THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR
# IMPLIED WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED
# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
#------------------------------------------------------------------------------------------------
#		Name:	Image2Model I
#			By:	sdmitch
#	 Usage:	Import all images of selected directory, make into component and save to individual model.
#		Note:	
#					
#		Date:	Apr 2012
#------------------------------------------------------------------------------------------------
#
	require 'sketchup'
#
if not file_loaded?(File.basename(__FILE__))
    UI.menu('Plugins').add_item('Image 2 Model I') { Image_2_Model_I.import_images }
	file_loaded(File.basename(__FILE__))
end

module Image_2_Model_I

	def self.import_images
		mod=Sketchup.active_model
		ent=mod.active_entities
		sel=mod.selection
		# get the source folder location of the images
		image_dir = "c:/users/public" if !image_dir
		image_path = UI.openpanel "Image File Location",image_dir,"*.*"
		if !image_path then return end
		# remove the file name from the path and chang \ to /
		image_dir = File.dirname(image_path);image_dir.gsub!("\\","/")
		# get an array of filenames of all files in the selected directory
		image_files = Dir.entries(image_dir)
		# get the destination folder for the models
		model_dir = "c:/users/public" if !model_dir
		model_path = UI.savepanel "Model Save Location",model_dir,"Image.skp"
		if !model_path then return end
		# remove the file name from the path and chang \ to /
		model_dir = File.dirname(model_path);model_dir.gsub!("\\","/")
		# get user input for width and orientation
		@standup = "Yes" if !@standup;@width = 1.0.m if !@width; 
		input = inputbox(["Standup:","  Width:"],[@standup,@width],["Yes|No"],"Image 2 Model")
		if !input then return end
		# copy the input to the appropriate variables
		@standup = input[0]; @width = input[1].to_l
		# define the image rotation transformation
		trr=Geom::Transformation.rotation(ORIGIN,X_AXIS,90.degrees)
		# process the image files in the source folder making sure that it is a image file
		for image in image_files
			if image[0,1] != "." && [".jpg",".png",".tif",".bmp",".gif",".tga",".epx"].include?(File.extname(image))
				Sketchup.file_new; ent.clear!; # start with a new file and make sure it is empty.
				Sketchup.send_action "viewFront:"; # select front view
				# import the image and place at the model origin
				img = ent.add_image("#{image_dir}/#{image}",ORIGIN,@width)
				# get the image dimensions and scale according to the pixels per inch
				# pix_wid = img.pixelwidth; pix_hgt = img.pixelheight
				# x_scl = pix_wid/pxi; y_scl = pix_hgt/pxi
				# trs = Geom::Transformation.scaling(ORIGIN,x_scl,y_scl,1.0)
				#	img.transform! trs
				# stand it up if needed
				img.transform! trr if @standup == "Yes"
				Sketchup.send_action "viewZoomExtents:"
				# explode the image, hide the edges and put in group
				img.explode; ent.each{|e| e.hidden=true if e.is_a?(Sketchup::Edge)}
				grp = ent.add_group ent.to_a; 
				# convert the group to a component
				cmp = grp.to_component
				# make it face the camera
				cmp.definition.behavior.always_face_camera = true
				cmp.definition.behavior.shadows_face_sun = true
				# move the component transformation origin to the bottom center
				tran=cmp.transformation
				cde=cmp.definition.entities
				org=cmp.transformation.origin
				ctr=Geom::Point3d.new(@width/2.0,0,0)
				px,py,pz=ctr.to_a
				t=tran.to_a; t[12]=px;t[13]=py;t[14]=pz
				cmp.transformation=tran.set!(t)
				tr=Geom::Transformation.new(org-ctr)
				cde.transform_entities(tr,cde.to_a)
				org=cmp.transformation.origin
				tr=Geom::Transformation.new(ORIGIN-ctr)
				cmp.transform! tr
				# save the model
				image[-3,3]="skp"; skp = mod.save "#{model_dir}/#{image}"
			end
		end
	end
	
end
